@@ -40,6 +40,7 @@ from rest_framework.request import Request
 
 from .. import humanize
 from ..api.coupons import CouponQuerysetMixin, SmartCouponListMixin
+from ..api.subscriptions import ActiveSubscribersMixin, ChurnedSubscribersMixin
 from ..api.transactions import (BillingsQuerysetMixin,
     SmartTransactionListMixin, TransactionQuerysetMixin, TransferQuerysetMixin)
 from ..api.users import RegisteredQuerysetMixin
@@ -47,8 +48,7 @@ from ..compat import six
 from ..metrics.base import (abs_monthly_balances, monthly_balances,
     month_periods)
 from ..mixins import (CartItemSmartListMixin, ProviderMixin,
-    MetricsMixin, ChurnedQuerysetMixin, SubscriptionSmartListMixin,
-    SubscribedQuerysetMixin, UserSmartListMixin, as_html_description)
+    MetricsMixin, UserSmartListMixin, as_html_description)
 from ..models import BalanceLine, CartItem, Coupon
 from ..utils import datetime_or_now
 
@@ -57,6 +57,7 @@ class CSVDownloadView(View):
 
     basename = 'download'
     headings = []
+    filter_backends = []
 
     @staticmethod
     def encode(text):
@@ -195,6 +196,7 @@ class CartItemDownloadView(CartItemSmartListMixin, CartItemQuerysetMixin,
 
     @property
     def coupon_code(self):
+        #pylint:disable=attribute-defined-outside-init
         if not hasattr(self, '_coupon_code'):
             self._coupon_code = self.kwargs.get(self.coupon_url_kwarg)
         return self._coupon_code
@@ -206,6 +208,7 @@ class CartItemDownloadView(CartItemSmartListMixin, CartItemQuerysetMixin,
                 code=self.coupon_code)
             return [coupon]
         view = CouponDownloadView()
+        #pylint:disable=attribute-defined-outside-init
         if hasattr(view, 'setup'):
             # `setup` is only defined in Django 2.2+
             view.setup(self.request, *self.args, **self.kwargs)
@@ -301,29 +304,18 @@ class SubscriptionBaseDownloadView(CSVDownloadView):
         ]
 
 
-class ActiveSubscriptionBaseDownloadView(SubscribedQuerysetMixin,
-                                         SubscriptionBaseDownloadView):
+class ActiveSubscriptionDownloadView(ActiveSubscribersMixin,
+                                     SubscriptionBaseDownloadView):
 
     subscriber_type = 'active'
 
-class ActiveSubscriptionDownloadView(SubscriptionSmartListMixin,
-                                     ActiveSubscriptionBaseDownloadView):
 
-    pass
-
-
-class ChurnedSubscriptionBaseDownloadView(ChurnedQuerysetMixin,
-                                         SubscriptionBaseDownloadView):
+class ChurnedSubscriptionDownloadView(ChurnedSubscribersMixin,
+                                      SubscriptionBaseDownloadView):
 
     subscriber_type = 'churned'
 
 
-class ChurnedSubscriptionDownloadView(SubscriptionSmartListMixin,
-                                      ChurnedSubscriptionBaseDownloadView):
-
-    pass
-
-
 class TransactionDownloadView(SmartTransactionListMixin,
                            TransactionQuerysetMixin, CSVDownloadView):
 
