@@ -36,7 +36,7 @@ from django.views.generic import (CreateView, DetailView, ListView,
 
 from . import RedirectFormMixin
 from .. import settings, signals
-from ..compat import reverse, NoReverseMatch
+from ..compat import reverse, NoReverseMatch, gettext_lazy as _
 from ..decorators import _valid_manager
 from ..forms import (OrganizationForm, OrganizationCreateForm,
     ManagerAndOrganizationForm)
@@ -142,13 +142,13 @@ djaodjin-saas/tree/master/saas/templates/saas/profile/subscribers.html>`__).
         tabs = [{
             "is_active": True,
             "slug": "subscribed",
-            "title": "Active",
+            "title": _("Active"),
             "urls": {"download": reverse(
               'saas_subscriber_pipeline_download_subscribed', args=(provider,))
             }},
                 {
             "slug": "churned",
-            "title": "Churned",
+            "title": _("Churned"),
             "urls": {"download": reverse(
               'saas_subscriber_pipeline_download_churned', args=(provider,))
             }}]
@@ -158,7 +158,7 @@ djaodjin-saas/tree/master/saas/templates/saas/profile/subscribers.html>`__).
             args=(provider,))
         })
         if provider.is_broker:
-            update_context_urls(context, {
+            context.update({
                 'registered': {'urls': {'download': reverse(
                 'saas_subscriber_pipeline_download_registered')}}})
         return context
@@ -255,7 +255,7 @@ class OrganizationCreateView(RedirectFormMixin, CreateView):
     template_name = "saas/profile/new.html"
     implicit_create_on_none = False
 
-    def create_organization_from_user(self, user):#pylint:disable=no-self-use
+    def create_organization_from_user(self, user):
         with transaction.atomic():
             organization = self.organization_model.objects.create(
                 slug=user.username,
@@ -269,6 +269,7 @@ class OrganizationCreateView(RedirectFormMixin, CreateView):
 
     def form_valid(self, form):
         with transaction.atomic():
+            #pylint:disable=attribute-defined-outside-init
             self.object = form.save()
             if not _valid_manager(self.request, [get_broker()]):
                 # If it is a manager of the broker platform creating
@@ -306,6 +307,7 @@ class OrganizationCreateView(RedirectFormMixin, CreateView):
         if count == 0:
             if self.get_implicit_create_on_none():
                 try:
+                    #pylint:disable=attribute-defined-outside-init
                     self.object = self.create_organization_from_user(
                         request.user)
                     return http.HttpResponseRedirect(self.get_success_url())
